@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -18,8 +18,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_CONFIG_H
-#define __WEECHAT_CONFIG_H 1
+#ifndef WEECHAT_CONFIG_H
+#define WEECHAT_CONFIG_H 1
 
 #include <regex.h>
 #include "wee-config-file.h"
@@ -66,6 +66,12 @@ enum t_config_look_prefix_buffer_align
     CONFIG_LOOK_PREFIX_BUFFER_ALIGN_RIGHT,
 };
 
+enum t_config_look_hotlist_remove
+{
+    CONFIG_LOOK_HOTLIST_REMOVE_BUFFER = 0,
+    CONFIG_LOOK_HOTLIST_REMOVE_MERGED,
+};
+
 enum t_config_look_hotlist_sort
 {
     CONFIG_LOOK_HOTLIST_SORT_GROUP_TIME_ASC = 0,
@@ -135,6 +141,7 @@ extern struct t_config_option *config_look_color_nick_offline;
 extern struct t_config_option *config_look_color_pairs_auto_reset;
 extern struct t_config_option *config_look_color_real_white;
 extern struct t_config_option *config_look_command_chars;
+extern struct t_config_option *config_look_command_incomplete;
 extern struct t_config_option *config_look_confirm_quit;
 extern struct t_config_option *config_look_day_change;
 extern struct t_config_option *config_look_day_change_message_1date;
@@ -144,7 +151,7 @@ extern struct t_config_option *config_look_emphasized_attributes;
 extern struct t_config_option *config_look_highlight;
 extern struct t_config_option *config_look_highlight_regex;
 extern struct t_config_option *config_look_highlight_tags;
-extern struct t_config_option *config_look_hotlist_add_buffer_if_away;
+extern struct t_config_option *config_look_hotlist_add_conditions;
 extern struct t_config_option *config_look_hotlist_buffer_separator;
 extern struct t_config_option *config_look_hotlist_count_max;
 extern struct t_config_option *config_look_hotlist_count_min_msg;
@@ -153,6 +160,7 @@ extern struct t_config_option *config_look_hotlist_names_length;
 extern struct t_config_option *config_look_hotlist_names_level;
 extern struct t_config_option *config_look_hotlist_names_merged_buffers;
 extern struct t_config_option *config_look_hotlist_prefix;
+extern struct t_config_option *config_look_hotlist_remove;
 extern struct t_config_option *config_look_hotlist_short_names;
 extern struct t_config_option *config_look_hotlist_sort;
 extern struct t_config_option *config_look_hotlist_suffix;
@@ -164,6 +172,7 @@ extern struct t_config_option *config_look_input_undo_max;
 extern struct t_config_option *config_look_item_time_format;
 extern struct t_config_option *config_look_item_buffer_filter;
 extern struct t_config_option *config_look_item_buffer_zoom;
+extern struct t_config_option *config_look_item_mouse_status;
 extern struct t_config_option *config_look_jump_current_to_previous_buffer;
 extern struct t_config_option *config_look_jump_previous_buffer_when_closing;
 extern struct t_config_option *config_look_jump_smart_back_to_buffer;
@@ -187,6 +196,8 @@ extern struct t_config_option *config_look_prefix_buffer_align_more;
 extern struct t_config_option *config_look_prefix_buffer_align_more_after;
 extern struct t_config_option *config_look_prefix_same_nick;
 extern struct t_config_option *config_look_prefix_suffix;
+extern struct t_config_option *config_look_bare_display_exit_on_input;
+extern struct t_config_option *config_look_bare_display_time_format;
 extern struct t_config_option *config_look_read_marker;
 extern struct t_config_option *config_look_read_marker_always_show;
 extern struct t_config_option *config_look_read_marker_string;
@@ -254,8 +265,10 @@ extern struct t_config_option *config_color_status_data_msg;
 extern struct t_config_option *config_color_status_data_other;
 extern struct t_config_option *config_color_status_data_private;
 extern struct t_config_option *config_color_status_filter;
+extern struct t_config_option *config_color_status_mouse;
 extern struct t_config_option *config_color_status_name;
 extern struct t_config_option *config_color_status_name_ssl;
+extern struct t_config_option *config_color_status_nicklist_count;
 extern struct t_config_option *config_color_status_number;
 extern struct t_config_option *config_color_status_more;
 extern struct t_config_option *config_color_status_time;
@@ -264,6 +277,7 @@ extern struct t_config_option *config_color_nicklist_group;
 extern struct t_config_option *config_color_nicklist_offline;
 
 extern struct t_config_option *config_completion_base_word_until_cursor;
+extern struct t_config_option *config_completion_command_inline;
 extern struct t_config_option *config_completion_default_template;
 extern struct t_config_option *config_completion_nick_add_space;
 extern struct t_config_option *config_completion_nick_completer;
@@ -313,4 +327,4 @@ extern int config_weechat_read ();
 extern int config_weechat_write ();
 extern void config_weechat_free ();
 
-#endif /* __WEECHAT_CONFIG_H */
+#endif /* WEECHAT_CONFIG_H */
