@@ -1,7 +1,7 @@
 /*
  * gui-curses-mouse.c - mouse functions for Curses GUI
  *
- * Copyright (C) 2011-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2011-2015 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -89,6 +89,9 @@ gui_mouse_enable ()
 {
     gui_mouse_enabled = 1;
     fprintf (stderr, "\033[?1005h\033[?1000h\033[?1002h");
+
+    (void) hook_signal_send ("mouse_enabled",
+                             WEECHAT_HOOK_SIGNAL_STRING, NULL);
 }
 
 /*
@@ -100,6 +103,9 @@ gui_mouse_disable ()
 {
     gui_mouse_enabled = 0;
     fprintf (stderr, "\033[?1002l\033[?1000l\033[?1005l");
+
+    (void) hook_signal_send ("mouse_disabled",
+                             WEECHAT_HOOK_SIGNAL_STRING, NULL);
 }
 
 /*
@@ -379,7 +385,6 @@ gui_mouse_event_code2key (const char *code)
      *   buttonX-gesture-right-long | >= 40 |
      */
 
-    distance = 0;
     if (key[0]
         && ((gui_mouse_event_x[0] != gui_mouse_event_x[1])
             || (gui_mouse_event_y[0] != gui_mouse_event_y[1])))
