@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,8 +17,8 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_RELAY_NETWORK_H
-#define __WEECHAT_RELAY_NETWORK_H 1
+#ifndef WEECHAT_RELAY_NETWORK_H
+#define WEECHAT_RELAY_NETWORK_H 1
 
 #ifdef HAVE_GNUTLS
 #include <gnutls/gnutls.h>
@@ -34,7 +34,8 @@ extern gnutls_dh_params_t *relay_gnutls_dh_params;
 #endif
 
 extern void relay_network_set_ssl_cert_key (int verbose);
+extern void relay_network_set_priority ();
 extern void relay_network_init ();
 extern void relay_network_end ();
 
-#endif /* __WEECHAT_RELAY_NETWORK_H */
+#endif /* WEECHAT_RELAY_NETWORK_H */
