@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,9 +17,9 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_XFER_COMPLETION_H
-#define __WEECHAT_XFER_COMPLETION_H 1
+#ifndef WEECHAT_XFER_COMPLETION_H
+#define WEECHAT_XFER_COMPLETION_H 1
 
 extern void xfer_completion_init ();
 
-#endif /* __WEECHAT_XFER_COMPLETION_H */
+#endif /* WEECHAT_XFER_COMPLETION_H */
