@@ -1,7 +1,7 @@
 /*
  * xfer-network.c - network functions for xfer plugin
  *
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -225,16 +225,14 @@ xfer_network_send_file_fork (struct t_xfer *xfer)
 
     switch (pid = fork ())
     {
-        /* fork failed */
-        case -1:
+        case -1:  /* fork failed */
             weechat_printf (NULL,
                             _("%s%s: unable to fork"),
                             weechat_prefix ("error"), XFER_PLUGIN_NAME);
             xfer_close (xfer, XFER_STATUS_FAILED);
             xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
             return;
-            /* child process */
-        case 0:
+        case 0:  /* child process */
             rc = setuid (getuid ());
             (void) rc;
             close (xfer->child_read);
@@ -298,16 +296,14 @@ xfer_network_recv_file_fork (struct t_xfer *xfer)
 
     switch (pid = fork ())
     {
-        /* fork failed */
-        case -1:
+        case -1:  /* fork failed */
             weechat_printf (NULL,
                             _("%s%s: unable to fork"),
                             weechat_prefix ("error"), XFER_PLUGIN_NAME);
             xfer_close (xfer, XFER_STATUS_FAILED);
             xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
             return;
-        /* child process */
-        case 0:
+        case 0:  /* child process */
             rc = setuid (getuid ());
             (void) rc;
             close (xfer->child_read);
@@ -525,6 +521,133 @@ xfer_network_timer_cb (void *arg_xfer, int remaining_calls)
     return WEECHAT_RC_OK;
 }
 
+/*
+ * Callback called when connecting to remote host (DCC chat only).
+ */
+
+int
+xfer_network_connect_chat_recv_cb (void *data, int status, int gnutls_rc,
+                                   int sock, const char *error,
+                                   const char *ip_address)
+{
+    struct t_xfer *xfer;
+    int flags;
+
+    /* make C compiler happy */
+    (void) gnutls_rc;
+    (void) ip_address;
+
+    xfer = (struct t_xfer*)data;
+
+    weechat_unhook (xfer->hook_connect);
+    xfer->hook_connect = NULL;
+
+    /* connection OK? */
+    if (status == WEECHAT_HOOK_CONNECT_OK)
+    {
+        xfer->sock = sock;
+
+        flags = fcntl (xfer->sock, F_GETFL);
+        if (flags == -1)
+            flags = 0;
+        if (fcntl (xfer->sock, F_SETFL, flags | O_NONBLOCK) == -1)
+        {
+            weechat_printf (NULL,
+                            _("%s%s: unable to set option \"nonblock\" "
+                              "for socket: error %d %s"),
+                            weechat_prefix ("error"), XFER_PLUGIN_NAME,
+                            errno, strerror (errno));
+            close (xfer->sock);
+            xfer->sock = -1;
+            xfer_close (xfer, XFER_STATUS_FAILED);
+            xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
+            return WEECHAT_RC_OK;
+        }
+
+        xfer->hook_fd = weechat_hook_fd (xfer->sock,
+                                         1, 0, 0,
+                                         &xfer_chat_recv_cb,
+                                         xfer);
+
+        xfer_chat_open_buffer (xfer);
+        xfer->status = XFER_STATUS_ACTIVE;
+        xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
+
+        return WEECHAT_RC_OK;
+    }
+
+    /* connection error */
+    switch (status)
+    {
+        case WEECHAT_HOOK_CONNECT_ADDRESS_NOT_FOUND:
+            weechat_printf (NULL,
+                            (xfer->proxy && xfer->proxy[0]) ?
+                            _("%s%s: proxy address \"%s\" not found") :
+                            _("%s%s: address \"%s\" not found"),
+                            weechat_prefix ("error"), XFER_PLUGIN_NAME,
+                            xfer->remote_address_str);
+            break;
+        case WEECHAT_HOOK_CONNECT_IP_ADDRESS_NOT_FOUND:
+            weechat_printf (NULL,
+                            (xfer->proxy && xfer->proxy[0]) ?
+                            _("%s%s: proxy IP address not found") :
+                            _("%s%s: IP address not found"),
+                            weechat_prefix ("error"), XFER_PLUGIN_NAME);
+            break;
+        case WEECHAT_HOOK_CONNECT_CONNECTION_REFUSED:
+            weechat_printf (NULL,
+                            (xfer->proxy && xfer->proxy[0]) ?
+                            _("%s%s: proxy connection refused") :
+                            _("%s%s: connection refused"),
+                            weechat_prefix ("error"), XFER_PLUGIN_NAME);
+            break;
+        case WEECHAT_HOOK_CONNECT_PROXY_ERROR:
+            weechat_printf (NULL,
+                            _("%s%s: proxy fails to establish connection to "
+                              "server (check username/password if used and if "
+                              "server address/port is allowed by proxy)"),
+                            weechat_prefix ("error"), XFER_PLUGIN_NAME);
+            break;
+        case WEECHAT_HOOK_CONNECT_LOCAL_HOSTNAME_ERROR:
+            weechat_printf (NULL,
+                            _("%s%s: unable to set local hostname/IP"),
+                            weechat_prefix ("error"), XFER_PLUGIN_NAME);
+            break;
+        case WEECHAT_HOOK_CONNECT_MEMORY_ERROR:
+            weechat_printf (NULL,
+                            _("%s%s: not enough memory"),
+                            weechat_prefix ("error"), XFER_PLUGIN_NAME);
+            break;
+        case WEECHAT_HOOK_CONNECT_TIMEOUT:
+            weechat_printf (NULL,
+                            _("%s%s: timeout"),
+                            weechat_prefix ("error"), XFER_PLUGIN_NAME);
+            break;
+        case WEECHAT_HOOK_CONNECT_SOCKET_ERROR:
+            weechat_printf (NULL,
+                            _("%s%s: unable to create socket"),
+                            weechat_prefix ("error"), XFER_PLUGIN_NAME);
+            break;
+        default:
+            weechat_printf (NULL,
+                            _("%s%s: unable to connect: unexpected error (%d)"),
+                            weechat_prefix ("error"), XFER_PLUGIN_NAME,
+                            status);
+            break;
+    }
+    if (error && error[0])
+    {
+        weechat_printf (NULL,
+                        _("%s%s: error: %s"),
+                        weechat_prefix ("error"), XFER_PLUGIN_NAME, error);
+    }
+
+    xfer_close (xfer, XFER_STATUS_FAILED);
+    xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
+
+    return WEECHAT_RC_OK;
+}
+
 /*
  * Connects to another host.
  *
@@ -548,7 +671,7 @@ xfer_network_connect (struct t_xfer *xfer)
         /* create socket */
         if (xfer->sock < 0)
         {
-            xfer->sock = socket (xfer->remote_address->sa_family, SOCK_STREAM,
+            xfer->sock = socket (xfer->local_address->sa_family, SOCK_STREAM,
                                  0);
             if (xfer->sock < 0)
                 return 0;
@@ -583,26 +706,12 @@ xfer_network_connect (struct t_xfer *xfer)
     /* for chat receiving, connect to listening host */
     if (xfer->type == XFER_TYPE_CHAT_RECV)
     {
-        xfer->sock = weechat_network_connect_to (xfer->proxy,
-                                                 xfer->remote_address,
-                                                 xfer->remote_address_length);
-        if (xfer->sock < 0)
-            return 0;
-
-        flags = fcntl (xfer->sock, F_GETFL);
-        if (flags == -1)
-            flags = 0;
-        if (fcntl (xfer->sock, F_SETFL, flags | O_NONBLOCK) == -1)
-        {
-            close (xfer->sock);
-            xfer->sock = -1;
-            return 0;
-        }
-
-        xfer->hook_fd = weechat_hook_fd (xfer->sock,
-                                         1, 0, 0,
-                                         &xfer_chat_recv_cb,
-                                         xfer);
+        xfer->hook_connect = weechat_hook_connect (xfer->proxy,
+                                                   xfer->remote_address_str,
+                                                   xfer->port, 1, 0, NULL, NULL,
+                                                   0, "NONE", NULL,
+                                                   &xfer_network_connect_chat_recv_cb,
+                                                   xfer);
     }
 
     /* for file receiving, connection is made in child process (blocking) */
@@ -620,22 +729,14 @@ xfer_network_connect_init (struct t_xfer *xfer)
     if (!xfer_network_connect (xfer))
     {
         xfer_close (xfer, XFER_STATUS_FAILED);
-        xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
     }
     else
     {
         /* for a file: launch child process */
         if (XFER_IS_FILE(xfer->type))
-        {
-            xfer->status = XFER_STATUS_CONNECTING;
             xfer_network_recv_file_fork (xfer);
-        }
-        else
-        {
-            /* for a chat => associate with buffer */
-            xfer->status = XFER_STATUS_ACTIVE;
-            xfer_chat_open_buffer (xfer);
-        }
+
+        xfer->status = XFER_STATUS_CONNECTING;
     }
     xfer_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
 }
