@@ -1,7 +1,7 @@
 /*
  * test-string.cpp - test string functions
  *
- * Copyright (C) 2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2015 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -26,8 +26,9 @@ extern "C"
 #include <stdio.h>
 #include <string.h>
 #include <regex.h>
-#include "../tests/tests.h"
-#include "../src/core/wee-string.h"
+#include "tests/tests.h"
+#include "src/core/wee-string.h"
+#include "src/core/wee-hashtable.h"
 }
 
 #define ONE_KB 1000ULL
@@ -94,6 +95,8 @@ extern "C"
     STRCMP_EQUAL(__result, str);                                        \
     free (str);
 
+extern struct t_hashtable *string_hashtable_shared;
+
 TEST_GROUP(String)
 {
 };
@@ -402,8 +405,8 @@ TEST(String, ConvertEscapedChars)
                  string_convert_escaped_chars ("\\0123"));  /* invalid */
     WEE_TEST_STR("\x41", string_convert_escaped_chars ("\\x41"));
     WEE_TEST_STR("\x04z", string_convert_escaped_chars ("\\x4z"));
-    WEE_TEST_STR("\u0012zz", string_convert_escaped_chars ("\\u12zz"));
-    WEE_TEST_STR("\U00123456", string_convert_escaped_chars ("\\U00123456"));
+    WEE_TEST_STR(" zz", string_convert_escaped_chars ("\\u20zz"));
+    WEE_TEST_STR("\U00012345", string_convert_escaped_chars ("\\U00012345"));
     WEE_TEST_STR("\U00000123zzz",
                  string_convert_escaped_chars ("\\U00123zzz"));
     WEE_TEST_STR("",
@@ -690,16 +693,16 @@ TEST(String, Split)
     POINTERS_EQUAL(NULL, string_split ("", NULL, 0, 0, NULL));
     POINTERS_EQUAL(NULL, string_split ("", "", 0, 0, NULL));
 
-    argc = 1;
+    argc = -1;
     POINTERS_EQUAL(NULL, string_split (NULL, NULL, 0, 0, &argc));
     LONGS_EQUAL(0, argc);
-    argc = 1;
+    argc = -1;
     POINTERS_EQUAL(NULL, string_split (NULL, "", 0, 0, &argc));
     LONGS_EQUAL(0, argc);
-    argc = 1;
+    argc = -1;
     POINTERS_EQUAL(NULL, string_split ("", NULL, 0, 0, &argc));
     LONGS_EQUAL(0, argc);
-    argc = 1;
+    argc = -1;
     POINTERS_EQUAL(NULL, string_split ("", "", 0, 0, &argc));
     LONGS_EQUAL(0, argc);
 
@@ -709,6 +712,7 @@ TEST(String, Split)
     /* standard split */
     argv = string_split (" abc de  fghi ", " ", 0, 0, &argc);
     LONGS_EQUAL(3, argc);
+    CHECK(argv);
     STRCMP_EQUAL("abc", argv[0]);
     STRCMP_EQUAL("de", argv[1]);
     STRCMP_EQUAL("fghi", argv[2]);
@@ -718,6 +722,7 @@ TEST(String, Split)
     /* max 2 items */
     argv = string_split (" abc de  fghi ", " ", 0, 2, &argc);
     LONGS_EQUAL(2, argc);
+    CHECK(argv);
     STRCMP_EQUAL("abc", argv[0]);
     STRCMP_EQUAL("de", argv[1]);
     POINTERS_EQUAL(NULL, argv[2]);
@@ -726,6 +731,7 @@ TEST(String, Split)
     /* keep eol */
     argv = string_split (" abc de  fghi ", " ", 1, 0, &argc);
     LONGS_EQUAL(3, argc);
+    CHECK(argv);
     STRCMP_EQUAL("abc de  fghi", argv[0]);
     STRCMP_EQUAL("de  fghi", argv[1]);
     STRCMP_EQUAL("fghi", argv[2]);
@@ -735,6 +741,7 @@ TEST(String, Split)
     /* keep eol and max 2 items */
     argv = string_split (" abc de  fghi ", " ", 1, 2, &argc);
     LONGS_EQUAL(2, argc);
+    CHECK(argv);
     STRCMP_EQUAL("abc de  fghi", argv[0]);
     STRCMP_EQUAL("de  fghi", argv[1]);
     POINTERS_EQUAL(NULL, argv[2]);
@@ -759,6 +766,7 @@ TEST(String, SplitShared)
 
     argv = string_split_shared (" abc de  abc ", " ", 0, 0, &argc);
     LONGS_EQUAL(3, argc);
+    CHECK(argv);
     STRCMP_EQUAL("abc", argv[0]);
     STRCMP_EQUAL("de", argv[1]);
     STRCMP_EQUAL("abc", argv[2]);
@@ -786,15 +794,24 @@ TEST(String, SplitShell)
 
     POINTERS_EQUAL(NULL, string_split_shell (NULL, NULL));
 
+    /* test with an empty string */
+    argc = -1;
+    argv = string_split_shell ("", &argc);
+    LONGS_EQUAL(0, argc);
+    CHECK(argv);
+    POINTERS_EQUAL(NULL, argv[0]);
+    string_free_split (argv);
+
+    /* test with a real string (command + arguments) */
     argv = string_split_shell ("/path/to/bin arg1 \"arg2 here\" 'arg3 here'",
                                &argc);
     LONGS_EQUAL(4, argc);
+    CHECK(argv);
     STRCMP_EQUAL("/path/to/bin", argv[0]);
     STRCMP_EQUAL("arg1", argv[1]);
     STRCMP_EQUAL("arg2 here", argv[2]);
     STRCMP_EQUAL("arg3 here", argv[3]);
     POINTERS_EQUAL(NULL, argv[4]);
-
     string_free_split (argv);
 
     /* free split with NULL */
@@ -815,6 +832,7 @@ TEST(String, SplitCommand)
     POINTERS_EQUAL(NULL, string_split_command (NULL, ';'));
     POINTERS_EQUAL(NULL, string_split_command ("", ';'));
     argv = string_split_command ("abc;de;fghi", ';');
+    CHECK(argv);
     STRCMP_EQUAL("abc", argv[0]);
     STRCMP_EQUAL("de", argv[1]);
     STRCMP_EQUAL("fghi", argv[2]);
@@ -1066,5 +1084,35 @@ TEST(String, Input)
 
 TEST(String, Shared)
 {
-    /* TODO: write tests */
+    const char *str1, *str2, *str3;
+    int count;
+
+    count = string_hashtable_shared->items_count;
+
+    str1 = string_shared_get ("this is a test");
+    CHECK(str1);
+
+    LONGS_EQUAL(count + 1, string_hashtable_shared->items_count);
+
+    str2 = string_shared_get ("this is a test");
+    CHECK(str2);
+    POINTERS_EQUAL(str1, str2);
+
+    LONGS_EQUAL(count + 1, string_hashtable_shared->items_count);
+
+    str3 = string_shared_get ("this is another test");
+    CHECK(str3);
+    CHECK(str1 != str3);
+    CHECK(str2 != str3);
+
+    LONGS_EQUAL(count + 2, string_hashtable_shared->items_count);
+
+    string_shared_free (str1);
+    LONGS_EQUAL(count + 2, string_hashtable_shared->items_count);
+
+    string_shared_free (str2);
+    LONGS_EQUAL(count + 1, string_hashtable_shared->items_count);
+
+    string_shared_free (str3);
+    LONGS_EQUAL(count + 0, string_hashtable_shared->items_count);
 }
